@@ -29,7 +29,7 @@ jomo1con<- function(Y, X=NULL, beta.start=NULL, l1cov.start=NULL, l1cov.prior=NU
   imp=matrix(0,nrow(Y)*(nimp+1),ncol(Y)+ncol(X)+2)
   imp[1:nrow(Y),1:ncol(Y)]=Y
   imp[1:nrow(X), (ncol(Y)+1):(ncol(Y)+ncol(X))]=X
-  imp[1:nrow(X), (ncol(Y)+ncol(X)+2)]=c(1:nrow(Y))
+  imp[1:nrow(X), (ncol(Y)+ncol(X)+1)]=c(1:nrow(Y))
   Yimp=Y
   Yimp2=matrix(0, nrow(Y),ncol(Y))
   imp[(nrow(X)+1):(2*nrow(X)),(ncol(Y)+1):(ncol(Y)+ncol(X))]=X
@@ -63,17 +63,21 @@ jomo1con<- function(Y, X=NULL, beta.start=NULL, l1cov.start=NULL, l1cov.prior=NU
     Yimp=Yimp2
     if (output==1) cat("Imputation number ", i, "registered", "\n")
   }
+  imp<-data.frame(imp)
+  if (is.null(colnamy)) colnamy=paste("Y", 1:ncol(Y), sep = "")
+  if (is.null(colnamx)) colnamx=paste("X", 1:ncol(X), sep = "")
+  dimnames(betapost)[1] <- list(colnamx)
+  dimnames(betapost)[2] <- list(colnamy)
+  dimnames(omegapost)[1] <- list(colnamy)
+  dimnames(omegapost)[2] <- list(colnamy)
   betapostmean<-apply(betapost, c(1,2), mean)
   omegapostmean<-apply(omegapost, c(1,2), mean)
   if (output==1) {
     cat("The posterior mean of the fixed effects estimates is:\n")
-    print(betapostmean)
-    cat("The posterior covariance matrix is:\n")
+    print(t(betapostmean))
+    cat("\nThe posterior covariance matrix is:\n")
     print(omegapostmean)
   }
-  imp<-data.frame(imp)
-  if (is.null(colnamy)) colnamy=paste("Y", 1:ncol(Y), sep = "")
-  if (is.null(colnamx)) colnamx=paste("X", 1:ncol(X), sep = "")
   colnames(imp)<-c(colnamy,colnamx,"id","Imputation")
   return(imp)
 }
\ No newline at end of file
