@@ -120,20 +120,6 @@ jomo1rancat <-
       imp[(i*nrow(X)+1):((i+1)*nrow(X)),1:ncol(Y)]=Y.cat
       if (output==1) cat("Imputation number ", i, "registered", "\n")
     }
-    betapostmean<-apply(betapost, c(1,2), mean)
-    upostmean<-apply(upostall, c(1,2), mean)
-    omegapostmean<-apply(omegapost, c(1,2), mean)
-    covupostmean<-apply(covupost, c(1,2), mean)
-    if (output==1) {
-      cat("The posterior mean of the fixed effects estimates is:\n")
-      print(betapostmean)
-      cat("The posterior mean of the random effects estimates is:\n")
-      print(upostmean)
-      cat("The posterior mean of the level 1 covariance matrices is:\n")
-      print(omegapostmean)
-      cat("The posterior mean of the level 2 covariance matrix is:\n")
-      print(covupostmean)
-    }
     imp<-data.frame(imp)
     for (i in 1:ncol(Y)) {
       imp[,i]<-as.factor(imp[,i]) 
@@ -150,5 +136,36 @@ jomo1rancat <-
     if (is.null(colnamz)) colnamz=paste("Z", 1:ncol(Z), sep = "")
     if (is.null(colnamx)) colnamx=paste("X", 1:ncol(X), sep = "")
     colnames(imp)<-c(colnamycat,colnamx,colnamz,"clus","id","Imputation")
+    cnycatcomp<-rep(NA,(sum(Y.numcat)-length(Y.numcat)))
+    count=0
+    for ( j in 1:ncol(Y.cat)) {
+      for (k in 1:(Y.numcat[j]-1)) {
+        cnycatcomp[count+k]<-paste(colnamycat[j],k,sep=".")
+      }
+      count=count+Y.numcat[j]-1
+    }
+    dimnames(betapost)[1] <- list(colnamx)
+    dimnames(betapost)[2] <- list(cnycatcomp)
+    dimnames(omegapost)[1] <- list(cnycatcomp)
+    dimnames(omegapost)[2] <- list(cnycatcomp)
+    colnamcovu<-paste(cnycatcomp,rep(colnamz,each=ncol(omegapost)),sep="*")
+    dimnames(covupost)[1] <- list(colnamcovu)
+    dimnames(covupost)[2] <- list(colnamcovu)
+    dimnames(upostall)[1]<-list(levels(clus))
+    dimnames(upostall)[2]<-list(colnamcovu)
+    betapostmean<-apply(betapost, c(1,2), mean)    
+    upostmean<-apply(upostall, c(1,2), mean)
+    omegapostmean<-apply(omegapost, c(1,2), mean)
+    covupostmean<-apply(covupost, c(1,2), mean)
+    if (output==1) {
+      cat("The posterior mean of the fixed effects estimates is:\n")
+      print(t(betapostmean))
+      cat("\nThe posterior mean of the random effects estimates is:\n")
+      print(upostmean)
+      cat("\nThe posterior mean of the level 1 covariance matrices is:\n")
+      print(omegapostmean)
+      cat("\nThe posterior mean of the level 2 covariance matrix is:\n")
+      print(covupostmean)
+    }
     return(imp)
   }
